pub struct MouseSourceV2Marker;Trait Implementations
Sourceimpl Clone for MouseSourceV2Marker
impl Clone for MouseSourceV2Marker
Sourcefn clone(&self) -> MouseSourceV2Marker
fn clone(&self) -> MouseSourceV2Marker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MouseSourceV2Marker
Sourceimpl Debug for MouseSourceV2Marker
impl Debug for MouseSourceV2Marker
impl Eq for MouseSourceV2Marker
Sourceimpl Hash for MouseSourceV2Marker
impl Hash for MouseSourceV2Marker
Sourceimpl Ord for MouseSourceV2Marker
impl Ord for MouseSourceV2Marker
Sourcefn cmp(&self, other: &MouseSourceV2Marker) -> Ordering
fn cmp(&self, other: &MouseSourceV2Marker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for MouseSourceV2Marker
impl PartialEq for MouseSourceV2Marker
Sourceimpl PartialOrd for MouseSourceV2Marker
impl PartialOrd for MouseSourceV2Marker
Sourceimpl ProtocolMarker for MouseSourceV2Marker
impl ProtocolMarker for MouseSourceV2Marker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) MouseSourceV2"
const DEBUG_NAME: &'static str = "(anonymous) MouseSourceV2"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = MouseSourceV2Proxy
type Proxy = MouseSourceV2Proxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = MouseSourceV2RequestStream
type RequestStream = MouseSourceV2RequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = MouseSourceV2SynchronousProxy
type SynchronousProxy = MouseSourceV2SynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for MouseSourceV2Marker