pub struct TouchSourceV2Marker;Trait Implementations
Sourceimpl Clone for TouchSourceV2Marker
impl Clone for TouchSourceV2Marker
Sourcefn clone(&self) -> TouchSourceV2Marker
fn clone(&self) -> TouchSourceV2Marker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TouchSourceV2Marker
Sourceimpl Debug for TouchSourceV2Marker
impl Debug for TouchSourceV2Marker
impl Eq for TouchSourceV2Marker
Sourceimpl Hash for TouchSourceV2Marker
impl Hash for TouchSourceV2Marker
Sourceimpl Ord for TouchSourceV2Marker
impl Ord for TouchSourceV2Marker
Sourcefn cmp(&self, other: &TouchSourceV2Marker) -> Ordering
fn cmp(&self, other: &TouchSourceV2Marker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for TouchSourceV2Marker
impl PartialEq for TouchSourceV2Marker
Sourceimpl PartialOrd for TouchSourceV2Marker
impl PartialOrd for TouchSourceV2Marker
Sourceimpl ProtocolMarker for TouchSourceV2Marker
impl ProtocolMarker for TouchSourceV2Marker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) TouchSourceV2"
const DEBUG_NAME: &'static str = "(anonymous) TouchSourceV2"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = TouchSourceV2Proxy
type Proxy = TouchSourceV2Proxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = TouchSourceV2RequestStream
type RequestStream = TouchSourceV2RequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = TouchSourceV2SynchronousProxy
type SynchronousProxy = TouchSourceV2SynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for TouchSourceV2Marker